import datetime

from django.test import TestCase, RequestFactory
from django.urls import reverse

from functions import create_user, create_appointment_type, create_appointment
from web.models import Item, Appointment
from web.views.kit import kit_requests
from web.views.notifications import get_today_midnight_date


class ViewFunctionsTests(TestCase):
    def setUp(self):
        self.factory = RequestFactory()
        self.user = create_user()

    def test_kit_requests(self):
        request = self.factory.get(reverse('web.views.kit_requests'))
        request.user = self.user
        response = kit_requests(request)
        self.assertEqual(response.status_code, 200)

    def test_kit_requests_2(self):
        item_name = "Test item to be ordered"
        item = Item.objects.create(disposable=True, name=item_name)
        appointment_type = create_appointment_type()
        appointment_type.required_equipment.add(item)
        appointment_type.save()

        appointment = create_appointment()
        appointment.datetime_when = get_today_midnight_date() + datetime.timedelta(days=2)
        appointment.appointment_types.add(appointment_type)
        appointment.save()

        request = self.factory.get(reverse('web.views.kit_requests'))
        request.user = self.user
        response = kit_requests(request)
        self.assertEqual(response.status_code, 200)

        self.assertTrue(item_name in response.content)

    def test_kit_requests_4(self):
        item_name = "Test item to be ordered"
        item = Item.objects.create(disposable=True, name=item_name)
        appointment_type = create_appointment_type()
        appointment_type.required_equipment.add(item)
        appointment_type.save()

        appointment = create_appointment()
        appointment.datetime_when = get_today_midnight_date() + datetime.timedelta(days=2)
        appointment.appointment_types.add(appointment_type)
        appointment.status = Appointment.APPOINTMENT_STATUS_CANCELLED
        appointment.save()

        request = self.factory.get(reverse('web.views.kit_requests'))
        request.user = self.user
        response = kit_requests(request)
        self.assertEqual(response.status_code, 200)

        self.assertFalse(item_name in response.content)

    def test_kit_requests_3(self):
        item_name = "Test item to be ordered"
        item = Item.objects.create(disposable=True, name=item_name)
        appointment_type = create_appointment_type()
        appointment_type.required_equipment.add(item)
        appointment_type.save()

        appointment = create_appointment()
        appointment.datetime_when = get_today_midnight_date() + datetime.timedelta(days=2)
        appointment.appointment_types.add(appointment_type)
        appointment.save()

        request = self.factory.get(reverse('web.views.kit_requests'))
        request.user = self.user
        response = kit_requests(request)
        self.assertEqual(response.status_code, 200)

        self.assertTrue(item_name in response.content)
