"""smash URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.10/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.conf.urls import url, include
    2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf import settings
from django.conf.urls import include
from django.conf.urls import url

from web import views

urlpatterns = [
    url(r'^appointments$', views.appointment.appointments, name='web.views.appointments'),
    url(r'^appointments/unfinished$', views.appointment.unfinished_appointments,
        name='web.views.unfinished_appointments'),
    url(r'^appointments/details/(?P<id>\d+)$', views.appointment.appointment_details,
        name='web.views.appointment_details'),
    url(r'^appointments/add/(?P<visit_id>\d+)$', views.appointment.appointment_add, name='web.views.appointment_add'),
    url(r'^appointments/add/general$', views.appointment.appointment_add, name='web.views.appointment_add'),
    url(r'^appointments/edit/(?P<id>\d+)$', views.appointment.appointment_edit, name='web.views.appointment_edit'),

    url(r'^visits$', views.visit.visits, name='web.views.visits'),
    url(r'^visits/exceeded$', views.visit.exceeded_visits, name='web.views.exceeded_visits'),
    url(r'^visits/unfinished$', views.visit.unfinished_visits, name='web.views.unfinished_visits'),
    url(r'^visits/approaching$', views.visit.approaching_visits_without_appointments,
        name='web.views.approaching_visits_without_appointments'),
    url(r'^visits/approaching_post_mail$', views.visit.approaching_visits_for_mail_contact,
        name='web.views.approaching_visits_for_mail_contact'),
    url(r'^visits/missing_appointments$', views.visit.visits_with_missing_appointments,
        name='web.views.visits_with_missing_appointments'),
    url(r'^visits/details/(?P<id>\d+)$', views.visit.visit_details, name='web.views.visit_details'),
    url(r'^visits/add$', views.visit.visit_add, name='web.views.visit_add'),
    url(r'^visits/add/(?P<subject_id>\d+)$', views.visit.visit_add, name='web.views.visit_add'),
    url(r'^visit/mark/(?P<id>\d+)/(?P<as_what>[A-z]+)$', views.visit.visit_mark, name='web.views.visit_mark'),

    url(r'^subjects$', views.subject.subjects, name='web.views.subjects'),
    url(r'^subjects/no_visit$', views.subject.subject_no_visits, name='web.views.subject_no_visits'),
    url(r'^subjects/equire_contact$', views.subject.subject_require_contact, name='web.views.subject_require_contact'),
    url(r'^subjects/add$', views.subject.subject_add, name='web.views.subject_add'),
    url(r'^subjects/subject_visit_details/(?P<id>\d+)$', views.subject.subject_visit_details,
        name='web.views.subject_visit_details'),
    url(r'^subjects/edit/(?P<id>\d+)$', views.subject.subject_edit, name='web.views.subject_edit'),
    url(r'^subjects/delete/(?P<id>\d+)$', views.subject.subject_delete, name='web.views.subject_delete'),
    url(r'^subjects/mark/(?P<id>\d+)/(?P<as_what>[A-z]+)$', views.subject.subject_mark, name='web.views.subject_mark'),

    url(r'^doctors$', views.doctor.doctors, name='web.views.doctors'),
    url(r'^doctors/add$', views.doctor.doctor_add, name='web.views.doctor_add'),
    url(r'^doctors/details/(?P<doctor_id>\d+)$', views.doctor.doctor_details, name='web.views.doctor_details'),
    url(r'^doctors/edit/(?P<doctor_id>\d+)$', views.doctor.doctor_edit, name='web.views.doctor_edit'),
    url(r'^doctors/availability/(?P<doctor_id>\d+)$', views.doctor.doctor_availability,
        name='web.views.doctor_availability'),
    url(r'^doctors/availability/(?P<doctor_id>\d+)/delete/(?P<availability_id>\d+)$',
        views.doctor.doctor_availability_delete,
        name='web.views.doctor_availability_delete'),

    url(r'^equipment_and_rooms$', views.equipment.equipment_and_rooms, name='web.views.equipment_and_rooms'),
    url(r'^equipment_and_rooms/eqdef$', views.equipment.equipment_def, name='web.views.equipment_def'),
    url(r'^equipment_and_rooms/kit_requests$', views.kit.kit_requests, name='web.views.kit_requests'),
    url(r'^equipment_and_rooms/kit_requests/(?P<start_date>[\w-]+)/$', views.kit.kit_requests_send_mail,
        name='web.views.kit_requests_send_mail'),
    url(r'^equipment_and_rooms/kit_requests/(?P<start_date>[\w-]+)/(?P<end_date>[\w-]+)/$',
        views.kit.kit_requests_send_mail, name='web.views.kit_requests_send_mail'),

    url(r'^mail_templates$', views.mails.mail_templates, name='web.views.mail_templates'),
    url(r'^statistics$', views.statistics.statistics, name='web.views.statistics'),

    url(r'^export$', views.export.export, name='web.views.export'),
    url(r'^export/(?P<type>[A-z]+)$', views.export.export_to_csv2, name='web.views.export_to_csv2'),

    url(r'^login$', views.auth.login, name='web.views.login'),
    url(r'^logout$', views.auth.logout, name='web.views.logout'),

    url(r'^$', views.index, name='web.views.index')
]

if settings.DEBUG:
    import debug_toolbar

    urlpatterns += [
        url(r'^__debug__/', include(debug_toolbar.urls)),
    ]
