# coding=utf-8
import csv

from django.contrib.auth.decorators import login_required
from django.http import HttpResponse

from notifications import get_today_midnight_date
from . import e500_error, wrap_response
from ..models import Subject, Appointment

__author__ = 'Valentin Grouès'


@login_required
def export_to_csv2(request, type="subjects"):
    # Create the HttpResponse object with the appropriate CSV header.
    response = HttpResponse(content_type='text/csv')
    response['Content-Disposition'] = 'attachment; filename="' + type + '-' + get_today_midnight_date().strftime(
        "%Y-%m-%d") + '.csv"'

    writer = csv.writer(response, quotechar=str(u'"'), quoting=csv.QUOTE_ALL)
    if type == "subjects":
        write_subjects_to_csv(writer)
    elif type == "appointments":
        write_appointments_to_csv(writer)
    else:
        return e500_error(request)
    return response


def write_subjects_to_csv(writer):
    subject_fields = []
    for field in Subject._meta.fields:
        if field.name != "ID":
            subject_fields.append(field)

    field_names = []
    for field in subject_fields:
        field_names.append(field.verbose_name)

    writer.writerow(field_names)

    subjects = Subject.objects.order_by('-last_name')
    for subject in subjects:
        row = []
        for field in subject_fields:
            row.append(getattr(subject, field.name))
        writer.writerow([unicode(s).replace("\n", ";").replace("\r", ";").encode("utf-8") for s in row])


def write_appointments_to_csv(writer):
    appointments_fields = []
    for field in Appointment._meta.fields:
        if field.name != "visit" and field.name != "id" and field.name != "worker_assigned" and field.name != "appointment_types" and field.name != "room" and field.name != "flying_team":
            appointments_fields.append(field)

    field_names = ['ND number', 'Family name', 'Name', 'Visit']
    for field in appointments_fields:
        field_names.append(field.verbose_name)

    writer.writerow(field_names)

    appointments = Appointment.objects.order_by('-datetime_when')

    for appointment in appointments:
        row = [appointment.visit.subject.nd_number, appointment.visit.subject.last_name,
               appointment.visit.subject.first_name, appointment.visit.follow_up_title()]
        for field in appointments_fields:
            row.append(getattr(appointment, field.name))
        type_string = ""
        for type in appointment.appointment_types.all():
            type_string += type.code + ","
        row.append(type_string)
        writer.writerow([unicode(s).replace("\n", ";").replace("\r", ";").encode("utf-8") for s in row])


def export(request):
    return wrap_response(request, 'export/index.html', {})
