# coding=utf-8
import datetime

from django.utils.dateparse import parse_datetime

from notifications import get_filter_locations, get_today_midnight_date
from . import wrap_response
from ..forms import KitRequestForm
from ..models import AppointmentType, Appointment

__author__ = 'Valentin Grouès'


def get_kit_requests(user, start_date=None, end_date=None):
    if start_date is None:
        start_date = get_today_midnight_date() + datetime.timedelta(days=1)
        end_date = start_date + datetime.timedelta(days=7)
    else:
        if isinstance(start_date, str):
            start_date = parse_datetime(start_date)
        if (end_date is not None) and (isinstance(end_date, str)):
            end_date = parse_datetime(end_date)

    appointment_types = AppointmentType.objects.filter(required_equipment__disposable=True)

    appointments = Appointment.objects.filter(
        appointment_types__in=appointment_types,
        datetime_when__gt=start_date,
        location__in=get_filter_locations(user),
        status=Appointment.APPOINTMENT_STATUS_SCHEDULED,
    )
    if end_date is not None:
        appointments = appointments.filter(datetime_when__lt=end_date)

    result = {
        'start_date': start_date,
        'end_date': end_date,
        'appointments': appointments,
    }
    return result


def get_kit_requests_data(request, start_date=None, end_date=None):
    form = KitRequestForm()
    if request.method == 'POST':
        form = KitRequestForm(request.POST)
        if form.is_valid():
            form_data = form.cleaned_data
            start_date = form_data.get('start_date')
            end_date = form_data.get('end_date')

    params = get_kit_requests(request.user, start_date, end_date)
    params.update({
        'form': form
    })
    return params


def kit_requests(request):
    return wrap_response(request, 'equipment_and_rooms/kit_requests.html', get_kit_requests_data(request))


def kit_requests_send_mail(request, start_date, end_date=None):
    return wrap_response(request, 'equipment_and_rooms/kit_requests_send_mail.html',
                         get_kit_requests_data(request, start_date, end_date))
