# coding=utf-8

from django.shortcuts import redirect, get_object_or_404

from notifications import get_subjects_with_no_visit, get_subjects_with_reminder
from . import wrap_response
from ..forms import SubjectAddForm, SubjectEditForm, VisitDetailForm
from ..models import Subject

__author__ = 'Valentin Grouès'


def subjects(request):
    subjects_list = Subject.objects.order_by('-last_name')
    context = {
        'subjects_list': subjects_list
    }

    return wrap_response(request, 'subjects/index.html', context)


def subject_add(request):
    if request.method == 'POST':
        form = SubjectAddForm(request.POST, request.FILES)
        if form.is_valid():
            screening_number = form.cleaned_data['screening_number']
            if screening_number == '':
                screening_number = get_new_screening_number()  # FIXME: method doesn't exist
            form.save()
            return redirect('web.views.subjects')
    else:
        form = SubjectAddForm()

    return wrap_response(request, 'subjects/add.html', {'form': form})


def subject_no_visits(request):
    subjects_list = get_subjects_with_no_visit(request.user).order_by('-last_name')
    context = {
        'subjects_list': subjects_list
    }

    return wrap_response(request, 'subjects/index.html', context)


def subject_require_contact(request):
    subjects_list = get_subjects_with_reminder(request.user).order_by('-last_name')
    context = {
        'subjects_list': subjects_list
    }

    return wrap_response(request, 'subjects/index.html', context)


def subject_edit(request, id):
    the_subject = get_object_or_404(Subject, id=id)
    if request.method == 'POST':
        form = SubjectEditForm(request.POST, request.FILES, instance=the_subject)
        if form.is_valid():
            form.save()
            return redirect('web.views.subjects')
    else:
        form = SubjectEditForm(instance=the_subject)
    return wrap_response(request, 'subjects/edit.html', {
        'form': form,
        'subject': the_subject
    })


def subject_delete(request, id):
    the_subject = get_object_or_404(Subject, id=id)
    if request.method == 'POST':
        the_subject.delete()
        return redirect('web.views.subjects')
    else:
        form = SubjectEditForm(instance=the_subject)
    return wrap_response(request, 'subjects/delete.html', {'form': form})


def subject_mark(request, id, as_what):
    who = get_object_or_404(Subject, id=id)
    if as_what == 'dead':
        who.mark_as_dead()
    elif as_what == 'rejected':
        who.mark_as_rejected()
    return redirect('web.views.subject_edit', id=id)


def subject_visit_details(request, id):
    locsubject = get_object_or_404(Subject, id=id)
    visits = locsubject.visit_set.all()
    endlist = []
    for vis in visits:
        assign = vis.appointment_set.all()
        finished = vis.is_finished
        visid = vis.id
        visit_title = vis.follow_up_title()
        visform = VisitDetailForm(instance=vis)
        endlist.append((visform, assign, finished, visid, visit_title))

    return wrap_response(request, 'subjects/visitdetails.html', {'display': endlist, "id": id})
