# coding=utf-8
from django.shortcuts import get_object_or_404, redirect

from notifications import get_active_visits_with_missing_appointments, get_unfinished_visits, \
    get_approaching_visits_without_appointments, get_approaching_visits_for_mail_contact, get_exceeded_visits, \
    waiting_for_appointment
from . import wrap_response
from ..forms import VisitDetailForm, SubjectDetailForm, VisitAddForm
from ..models import Visit, Appointment, Subject

__author__ = 'Valentin Grouès'


def visits(request):
    visit_list = Visit.objects.order_by('-datetime_begin')
    context = {
        'visit_list': visit_list
    }

    return wrap_response(request, 'visits/index.html', context)


def visits_with_missing_appointments(request):
    context = {
        'visit_list': get_active_visits_with_missing_appointments(request.user)
    }

    return wrap_response(request, 'visits/index.html', context)


def approaching_visits_without_appointments(request):
    context = {
        'visit_list': get_approaching_visits_without_appointments(request.user)
    }
    return wrap_response(request, 'visits/index.html', context)


def approaching_visits_for_mail_contact(request):
    context = {
        'visit_list': get_approaching_visits_for_mail_contact(request.user)
    }
    return wrap_response(request, 'visits/index.html', context)


def visit_details(request, id):
    displayed_visit = get_object_or_404(Visit, id=id)
    if request.method == 'POST':
        visit_form = VisitDetailForm(request.POST, request.FILES, instance=displayed_visit)
        if visit_form.is_valid():
            visit_form.save()
    else:
        visit_form = VisitDetailForm(instance=displayed_visit)

    visit_finished = displayed_visit.is_finished
    visit_id = displayed_visit.id
    displayed_subject = displayed_visit.subject
    list_of_appointments = displayed_visit.appointment_set.all()

    can_finish = not waiting_for_appointment(displayed_visit)

    for appointment in list_of_appointments:
        if appointment.status == Appointment.APPOINTMENT_STATUS_SCHEDULED:
            can_finish = False

    subject_form = SubjectDetailForm(instance=displayed_subject)

    return wrap_response(request, 'visits/details.html', {
        'vform': visit_form,
        'sform': subject_form,
        'loApp': list_of_appointments,
        'visFinished': visit_finished,
        'canFinish': can_finish,
        'vid': visit_id,
        'visit': displayed_visit})


def visit_mark(request, id, as_what):
    visit = get_object_or_404(Visit, id=id)
    if as_what == 'finished':
        visit.mark_as_finished()

    return redirect('web.views.visit_details', id=id)


def visit_add(request, subject_id=-1):
    if request.method == 'POST':
        form = VisitAddForm(request.POST, request.FILES)
        if form.is_valid():
            visit = form.save()
            return redirect('web.views.visit_details', visit.id)
    else:
        subjects = Subject.objects.filter(id=subject_id)
        subject = None
        if len(subjects) > 0:
            subject = subjects[0]
        form = VisitAddForm(initial={'subject': subject})

    return wrap_response(request, 'visits/add.html', {'form': form})


def exceeded_visits(request):
    context = {
        'visit_list': get_exceeded_visits(request.user)
    }
    return wrap_response(request, 'visits/index.html', context)


def unfinished_visits(request):
    context = {
        'visit_list': get_unfinished_visits(request.user)
    }

    return wrap_response(request, 'visits/index.html', context)
